==> mono-2.4.3.tar.bz2: mono-2.4.3/mcs/class/corlib/System.Reflection/TargetParameterCountException.cs <==
//
// System.Reflection.TargetParameterCountException.cs
//
// Author: Duncan Mak (duncan@ximian.com)
//
// (C) Ximian, Inc. http://www.ximian.com
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Runtime.Serialization;
using System.Globalization;
using System.Runtime.InteropServices;

namespace System.Reflection
{
#if NET_2_0
	[ComVisible (true)]
#endif
	[Serializable]
	public sealed class TargetParameterCountException : ApplicationException
	{
		public TargetParameterCountException ()
			: base (Locale.GetText ("Number of parameter does not match expected count."))
		{
		}

		public TargetParameterCountException (string message)
			: base (message)
		{
		}

		public TargetParameterCountException (string message, Exception inner)
			: base (message, inner)
		{
		}

		internal TargetParameterCountException (SerializationInfo info,
						       StreamingContext context)
			: base (info, context)
		{
		}
	}
}

==> mono-2.6.3.tar.bz2: mono-2.6.3/mcs/class/corlib/System.Reflection/TargetParameterCountException.cs <==
//
// System.Reflection.TargetParameterCountException.cs
//
// Author: Duncan Mak (duncan@ximian.com)
//
// (C) Ximian, Inc. http://www.ximian.com
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Runtime.Serialization;
using System.Globalization;
using System.Runtime.InteropServices;

namespace System.Reflection
{
#if NET_2_0
	[ComVisible (true)]
#endif
	[Serializable]
#if NET_2_1
	public sealed class TargetParameterCountException : Exception {
#else
	public sealed class TargetParameterCountException : ApplicationException {
#endif
		public TargetParameterCountException ()
			: base (Locale.GetText ("Number of parameter does not match expected count."))
		{
		}

		public TargetParameterCountException (string message)
			: base (message)
		{
		}

		public TargetParameterCountException (string message, Exception inner)
			: base (message, inner)
		{
		}

		internal TargetParameterCountException (SerializationInfo info,
						       StreamingContext context)
			: base (info, context)
		{
		}
	}
}
